# Generated by Django 4.2.7 on 2024-03-24 01:20

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('custom_admin', '0002_auto_20220826_1734'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='adminlog',
            name='hall',
        ),
        migrations.AlterField(
            model_name='adminlog',
            name='staff',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='admin_actions', to=settings.AUTH_USER_MODEL, verbose_name='Персонал'),
        ),
    ]



# Generated by Django 3.1.4 on 2022-08-18 10:46

from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('nodes', '0069_halltextinfo'),
        ('users', '0069_player_ignore_withdraw_restrictions'),
    ]

    operations = [
        migrations.CreateModel(
            name='AdminLog',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('section', models.CharField(max_length=64, verbose_name='Раздел')),
                ('action_type', models.CharField(choices=[('create', 'Создание'), ('edit', 'Редактирование'), ('delete', 'Удаление'), ('action', 'Действие')], max_length=12, verbose_name='Статус')),
                ('content', models.JSONField(default=dict, verbose_name='Содержимое действия')),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now, verbose_name='Время совершения действия')),
                ('hall', models.ForeignKey(blank=True, help_text='Зал, к которому относится действие', null=True, on_delete=django.db.models.deletion.PROTECT, related_name='admin_actions', to='nodes.hall', verbose_name='Зал')),
                ('staff', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='admin_actions', to='users.staff', verbose_name='Персонал')),
            ],
            options={
                'verbose_name': 'Лог действия',
                'verbose_name_plural': 'Лог действий',
            },
        ),
    ]



# Generated by Django 3.1.4 on 2022-08-26 14:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('custom_admin', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='adminlog',
            options={'verbose_name': 'Лог действия администратора', 'verbose_name_plural': 'Лог действий администраторов'},
        ),
        migrations.AddField(
            model_name='adminlog',
            name='title',
            field=models.CharField(blank=True, max_length=64, null=True, verbose_name='Заголовок'),
        ),
        migrations.AlterField(
            model_name='adminlog',
            name='action_type',
            field=models.CharField(choices=[('create', 'Создание'), ('edit', 'Редактирование'), ('action', 'Действие')], max_length=12, verbose_name='Тип действия'),
        ),
    ]



import json

from django.conf import os, settings
from django.shortcuts import render
from django.template.exceptions import TemplateDoesNotExist
from django.views import View

TEMPLATE_NOT_FOUND = '''
Custom admin cannot find template "{template}".
Make sure settings.TEMPLATES contains 'APP_DIRS': True
'''


class CustomAdminView(View):
    '''
    # Settings in case of h2ttps:
    USE_X_FORWARDED_HOST = True
    SECURE_PROXY_SSL_HEADER = ('HTTP_X_FORWARDED_PROTO', 'https')
    '''

    template = 'custom_admin/admin_index.html'

    def get(self, request):
        static_prefix = settings.CUSTOM_ADMIN.get('static_prefix') or '/static/custom_admin'

        admin_settings = {
            'title': settings.CUSTOM_ADMIN.get('title'),
            'base_admin_url': settings.CUSTOM_ADMIN.get('base_admin_url') or 'admin/',
            'static_prefix': static_prefix,
            'favicon_path': settings.CUSTOM_ADMIN.get('favicon_path') or os.path.join(static_prefix, 'favicon.ico'),
            'logo_image_path': settings.CUSTOM_ADMIN.get('logo_image_path') or os.path.join(static_prefix, 'default-logo.png'),
        }

        if not admin_settings.get('backend_prefix'):
            admin_settings['backend_prefix'] = request.build_absolute_uri('/custom_admin/')

        context = {
            'SETTINGS': admin_settings,
            'SETTINGS_JSON': json.dumps(admin_settings),
        }

        try:
            return render(request, self.template, context)
        except TemplateDoesNotExist as e:
            raise TemplateDoesNotExist(TEMPLATE_NOT_FOUND.format(template=self.template)) from e
